@@ -516,11 +516,7 @@ populate_window (GtkWidget * win,
     GtkRequisition requisition;
     gint img_width, img_height;
 
-#if GTK_CHECK_VERSION (3, 2, 0)
     vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-#else
-    vbox = gtk_vbox_new (FALSE, 0);
-#endif
     gtk_container_add (GTK_CONTAINER (win), vbox);
 
     /* pack the window with the image */
